@@ -19,7 +19,7 @@
 %                              September 2013                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1818,7 +1818,10 @@ static Image *ReadDDSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
   }
 
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -2699,8 +2702,9 @@ static MagickBooleanType WriteDDSImage(const ImageInfo *image_info,
   if (mipmaps > 0 && WriteMipmaps(image,pixelFormat,compression,mipmaps,
         clusterFit,weightByAlpha,&image->exception) == MagickFalse)
     return(MagickFalse);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
 
 static void WriteDDSInfo(Image *image, const size_t pixelFormat,
@@ -2827,7 +2831,7 @@ static void WriteFourCC(Image *image, const size_t compression,
 
       DDSVector4
         point,
-        points[16] = { 0 };
+        points[16] = { { 0, 0, 0, 0 } };
 
       size_t
         count = 0,
