@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -161,12 +161,12 @@ Image *AutoResizeImage(const Image *image,const char *option,
     *resized,
     *images;
 
+  size_t
+    sizes[MAX_SIZES]={256, 192, 128, 96, 64, 48, 40, 32, 24, 16};
+
   ssize_t
     i;
 
-  size_t
-    sizes[MAX_SIZES]={256,192,128,96,64,48,40,32,24,16};
-
   images=NULL;
   *count=0;
   i=0;
@@ -178,19 +178,15 @@ Image *AutoResizeImage(const Image *image,const char *option,
 
     while ((isspace((int) ((unsigned char) *p)) != 0))
       p++;
-
     size=(size_t)strtol(p,&q,10);
     if ((p == q) || (size < 16) || (size > 256))
         return((Image *) NULL);
-
     p=q;
     sizes[i++]=size;
-
     while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
       p++;
   }
-
-  if (i==0)
+  if (i == 0)
     i=10;
   *count=i;
   for (i=0; i < *count; i++)
@@ -199,7 +195,6 @@ Image *AutoResizeImage(const Image *image,const char *option,
       exception);
     if (resized == (Image *) NULL)
       return(DestroyImageList(images));
-
     if (images == (Image *) NULL)
       images=resized;
     else
@@ -207,7 +202,7 @@ Image *AutoResizeImage(const Image *image,const char *option,
   }
   return(images);
 }
-
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -235,11 +230,91 @@ Image *AutoResizeImage(const Image *image,const char *option,
 %    o exception: return any errors or warnings in this structure.
 %
 */
+
+static Image *Read1XImage(Image *image,ExceptionInfo *exception)
+{
+  size_t
+    columns,
+    rows;
+
+  ssize_t
+    i;
+
+  /*
+    Read Windows 1.0 Icon.
+  */
+  (void) ReadBlobLSBLong(image);  /* hot spot X/Y */
+  columns=(size_t) ReadBlobLSBShort(image);
+  rows=(size_t) (ReadBlobLSBShort(image));
+  (void) ReadBlobLSBShort(image);  /* width of bitmap in bytes */
+  (void) ReadBlobLSBShort(image);  /* cursor color */
+  if ((rows != 32 && rows != 64) || (columns != 32 && columns != 64))
+    ThrowImageException(CorruptImageError,"ImproperImageHeader");
+  /*
+    Convert bitmap scanline.
+  */
+  if (SetImageExtent(image,columns,rows) == MagickFalse)
+    return(DestroyImageList(image));
+  image->matte=MagickTrue;
+  if (AcquireImageColormap(image,3) == MagickFalse)
+    return(DestroyImageList(image));
+  image->colormap[1].opacity=TransparentOpacity;
+  for (i=0; i < 2; i++)
+  {
+    ssize_t
+      y;
+
+    for (y=0; y < (ssize_t) image->columns; y++)
+    {
+      IndexPacket
+        *indexes;
+
+      PixelPacket
+        *q;
+
+      ssize_t
+        x;
+
+      q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
+      if (q == (PixelPacket *) NULL)
+        break;
+      indexes=GetAuthenticIndexQueue(image);
+      for (x=0; x < (ssize_t) (image->columns-7); x+=8)
+      {
+        size_t
+          bit,
+          byte;
+
+        byte=(size_t) ReadBlobByte(image);
+        for (bit=0; bit < 8; bit++)
+        {
+          Quantum
+            index;
+
+          index=((byte & (0x80 >> bit)) != 0 ? (i == 0 ? 0x01 : 0x02) : 0x00);
+          if (i == 0)
+            SetPixelIndex(indexes+x+bit,index);
+          else
+            if (GetPixelIndex(indexes+x+bit) != 0x01)
+              SetPixelIndex(indexes+x+bit,index);
+          q++;
+        }
+      }
+      if (SyncAuthenticPixels(image,exception) == MagickFalse)
+        break;
+    }
+  }
+  (void) SyncImage(image);
+  if (CloseBlob(image) == MagickFalse)
+    return(DestroyImageList(image));
+  return(GetFirstImageInList(image));
+}
+
 static Image *ReadICONImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
   IconFile
-    icon_file = { 0 };
+    icon_file;
 
   IconInfo
     icon_info;
@@ -293,7 +368,11 @@ static Image *ReadICONImage(const ImageInfo *image_info,
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
+  (void) memset(&icon_file,0,sizeof(icon_file));
   icon_file.reserved=(short) ReadBlobLSBShort(image);
+  if ((icon_file.reserved == 0x0001) || (icon_file.reserved == 0x0101) ||
+      (icon_file.reserved == 0x0201))
+    return(Read1XImage(image,exception));
   icon_file.resource_type=(short) ReadBlobLSBShort(image);
   icon_file.count=(short) ReadBlobLSBShort(image);
   if ((icon_file.reserved != 0) ||
@@ -987,15 +1066,15 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             return(MagickFalse);
           }
         write_info=CloneImageInfo(image_info);
-        (void) CopyMagickString(write_info->magick,"PNG",MagickPathExtent);
+        (void) CopyMagickString(write_info->magick,"PNG32",MagickPathExtent);
         length=0;
 
         /* Don't write any ancillary chunks except for gAMA */
         (void) SetImageArtifact(write_image,"png:include-chunk","none,gama");
 
         /* Only write PNG32 formatted PNG (32-bit RGBA), 8 bits per channel */
-        (void) SetImageArtifact(write_image,"png:format","png32");
-        (void) SetImageArtifact(write_image,"png:color-type","6");
+        (void) SetImageArtifact(write_image,"png:IHDR.color-type-orig","6");
+        (void) SetImageArtifact(write_image,"png:IHDR.bit-depth-orig","8");
         png=(unsigned char *) ImageToBlob(write_info,write_image,&length,
           &image->exception);
         write_image=DestroyImageList(write_image);
