@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1736,7 +1736,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           break;
       }
   } while (c != EOF && ((c == 'i') || (c == 'I')));
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
@@ -1864,9 +1865,11 @@ static unsigned char *PopRunlengthPacket(Image *image,unsigned char *pixels,
         {
           *pixels++=(unsigned char) (value >> 24);
           *pixels++=(unsigned char) (value >> 16);
+          magick_fallthrough;
         }
         case 16:
           *pixels++=(unsigned char) (value >> 8);
+          magick_fallthrough;
         case 8:
         {
           *pixels++=(unsigned char) value;
@@ -2106,8 +2109,12 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           }
       }
     else
-      if (image->depth < 16)
-        (void) DeleteImageProperty(image,"quantum:format");
+      if ((quantum_info->format == FloatingPointQuantumFormat) &&
+          (image->depth < 16))
+        {
+          status=SetQuantumFormat(image,quantum_info,UnsignedQuantumFormat);
+          status=SetQuantumDepth(image,quantum_info,image->depth);
+        }
     compression=UndefinedCompression;
     if (image_info->compression != UndefinedCompression)
       compression=image_info->compression;
@@ -2803,6 +2810,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
