@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -353,8 +353,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     number_planes_filled=(number_planes % 2 == 0) ? number_planes :
       number_planes+1;
-    if ((number_pixels*number_planes_filled) != (size_t) (number_pixels*
-         number_planes_filled))
+    if (((MagickSizeType) number_pixels*number_planes_filled) != (size_t) (number_pixels*number_planes_filled))
       ThrowRLEException(ResourceLimitError,"MemoryAllocationFailed");
     pixel_info=AcquireVirtualMemory(image->columns,image->rows*
       MagickMax(number_planes_filled,4)*sizeof(*pixels));
@@ -716,7 +715,8 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
   } while ((count != 0) && (memcmp(magick,"\122\314",2) == 0));
   if (colormap != (unsigned char *) NULL)
     colormap=(unsigned char *) RelinquishMagickMemory(colormap);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
