@@ -82,7 +82,7 @@
 */
 #if defined(MAGICKCORE_WEBP_DELEGATE)
 static MagickBooleanType
-  WriteWEBPImage(const ImageInfo *,Image *,ExceptionInfo *);
+  WriteWEBPImage(const ImageInfo *,Image *);
 #endif
 
 /*
@@ -232,9 +232,9 @@ static int FillBasicWEBPInfo(Image *image,const uint8_t *stream,size_t length,
   return(webp_status);
 }
 
-static int ReadSingleWEBPImage(Image *image,const uint8_t *stream,
-  size_t length,WebPDecoderConfig *configure,ExceptionInfo *exception,
-  MagickBooleanType is_first)
+static int ReadSingleWEBPImage(const ImageInfo *image_info,Image *image,
+  const uint8_t *stream,size_t length,WebPDecoderConfig *configure,
+  ExceptionInfo *exception,MagickBooleanType is_first)
 {
   int
     webp_status;
@@ -291,6 +291,9 @@ static int ReadSingleWEBPImage(Image *image,const uint8_t *stream,
   if (IsWEBPImageLossless((unsigned char *) stream,length) != MagickFalse)
     image->quality=100;
 
+  if (image_info->ping != MagickFalse)
+    return(webp_status);
+
   webp_status=WebPDecode(stream,length,configure);
   if (webp_status != VP8_STATUS_OK)
     return(webp_status);
@@ -461,15 +464,17 @@ static int ReadAnimatedWEBPImage(const ImageInfo *image_info,Image *image,
             CloneImageProperties(image,original_image);
             image->page.x=(ssize_t) iter.x_offset;
             image->page.y=(ssize_t) iter.y_offset;
-            webp_status=ReadSingleWEBPImage(image,iter.fragment.bytes,
-              iter.fragment.size,configure,exception,MagickFalse);
+            webp_status=ReadSingleWEBPImage(image_info,image,
+              iter.fragment.bytes,iter.fragment.size,configure,exception,
+              MagickFalse);
           }
         else
           {
             image->page.x=(ssize_t) iter.x_offset;
             image->page.y=(ssize_t) iter.y_offset;
-            webp_status=ReadSingleWEBPImage(image,iter.fragment.bytes,
-              iter.fragment.size,configure,exception,MagickTrue);
+            webp_status=ReadSingleWEBPImage(image_info,image,
+              iter.fragment.bytes,iter.fragment.size,configure,exception,
+              MagickTrue);
           }
         if (webp_status != VP8_STATUS_OK)
           break;
@@ -581,7 +586,8 @@ static Image *ReadWEBPImage(const ImageInfo *image_info,
       webp_status=VP8_STATUS_UNSUPPORTED_FEATURE;
 #endif
     } else {
-      webp_status=ReadSingleWEBPImage(image,stream,length,&configure,exception,MagickFalse);
+      webp_status=ReadSingleWEBPImage(image_info,image,stream,length,
+        &configure,exception,MagickFalse);
     }
   }
 
@@ -1111,7 +1117,7 @@ static inline void SetIntegerOption(const ImageInfo *image_info,
 }
 
 static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
-  Image *image,ExceptionInfo * exception)
+  Image *image)
 {
   const char
     *value;
@@ -1134,7 +1140,7 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
   assert(image->signature == MagickCoreSignature);
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  status=OpenBlob(image_info,image,WriteBinaryBlobMode,exception);
+  status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   if ((image->columns > 16383UL) || (image->rows > 16383UL))
@@ -1142,8 +1148,13 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
   if (WebPConfigInit(&configure) == 0)
     ThrowWriterException(ResourceLimitError,"UnableToEncodeImageFile");
   if (image->quality != UndefinedCompressionQuality)
-    configure.quality=(float) image->quality;
-  if (image->quality >= 100)
+    {
+      configure.quality=(float) image->quality;
+#if WEBP_ENCODER_ABI_VERSION >= 0x020e
+      configure.near_lossless=(float) image->quality;
+#endif
+    }
+ if (image->quality >= 100)
     configure.lossless=1;
   SetBooleanOption(image_info,"webp:lossless",&configure.lossless);
   value=GetImageOption(image_info,"webp:image-hint");
@@ -1168,8 +1179,7 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
     &configure.alpha_compression);
   SetIntegerOption(image_info,"webp:alpha-filtering",
     &configure.alpha_filtering);
-  SetIntegerOption(image_info,"webp:alpha-quality",
-    &configure.alpha_quality);
+  SetIntegerOption(image_info,"webp:alpha-quality",&configure.alpha_quality);
   SetIntegerOption(image_info,"webp:filter-strength",
     &configure.filter_strength);
   SetIntegerOption(image_info,"webp:filter-sharpness",
@@ -1196,7 +1206,6 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
   SetBooleanOption(image_info,"webp:exact",&configure.exact);
 #endif
 #if WEBP_ENCODER_ABI_VERSION >= 0x020e
-  SetIntegerOption(image_info,"webp:near-lossless",&configure.near_lossless);
   SetBooleanOption(image_info,"webp:use-sharp-yuv",&configure.use_sharp_yuv);
 #endif
   if (((configure.target_size > 0) || (configure.target_PSNR > 0)) &&
@@ -1214,12 +1223,12 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
         (GetPreviousImageInList(image) == (Image *) NULL) &&
         (GetNextImageInList(image) != (Image *) NULL))
       status=WriteAnimatedWEBPImage(image_info,image,&configure,&webp_data,
-        exception);
+        &image->exception);
     else
       {
         WebPMemoryWriterInit(&writer);
         status=WriteSingleWEBPImage(image_info,image,&configure,&writer,
-          exception);
+          &image->exception);
         if (status == MagickFalse)
           WebPMemoryWriterClear(&writer);
         else
@@ -1229,19 +1238,21 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
           }
       }
     if (status != MagickFalse)
-      status=WriteWEBPImageProfile(image,&webp_data,exception);
+      status=WriteWEBPImageProfile(image,&webp_data,&image->exception);
     if (status != MagickFalse)
       (void) WriteBlob(image,webp_data.size,webp_data.bytes);
     WebPDataClear(&webp_data);
   }
 #else
   WebPMemoryWriterInit(&writer);
-  status=WriteSingleWEBPImage(image_info,image,&configure,&writer,exception);
+  status=WriteSingleWEBPImage(image_info,image,&configure,&writer,
+    &image->exception);
   if (status != MagickFalse)
     (void) WriteBlob(image,writer.size,writer.mem);
   WebPMemoryWriterClear(&writer);
 #endif
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
 #endif
