@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -177,37 +177,37 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image
     *image;
 
-  int
-    c;
-
-  MagickBooleanType
-    status;
-
   IndexPacket
     *indexes;
 
-  ssize_t
-    i,
-    x;
+  int
+    c;
 
-  PixelPacket
-    *q;
-
-  unsigned char
-    *p;
 
   long
     height,
     width;
 
+  MagickBooleanType
+    status;
+
+  MagickOffsetType
+    offset;
+
+  PixelPacket
+    *q;
+
   short int
     hex_digits[256];
 
   ssize_t
+    i,
+    x,
     y;
 
   unsigned char
-    *data;
+    *data,
+    *p;
 
   unsigned int
     bit,
@@ -261,6 +261,7 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Scan until hex digits.
   */
   version=11;
+  offset=TellBlob(image);
   while (ReadBlobString(image,buffer) != (char *) NULL)
   {
     if (sscanf(buffer,"static short %1024s = {",name) == 1)
@@ -280,7 +281,10 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       p++;
     if (LocaleCompare("bits[]",(char *) p) == 0)
       break;
+    offset=TellBlob(image);
   }
+  if (strchr(buffer,'{') != (char *) NULL)
+    (void) SeekBlob(image,offset+(strchr(buffer,'{')-buffer)+1,SEEK_SET);
   /*
     Initialize image structure.
   */
@@ -413,7 +417,10 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   data=(unsigned char *) RelinquishMagickMemory(data);
   (void) SyncImage(image);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -449,6 +456,7 @@ ModuleExport size_t RegisterXBMImage(void)
   entry->decoder=(DecodeImageHandler *) ReadXBMImage;
   entry->encoder=(EncodeImageHandler *) WriteXBMImage;
   entry->magick=(IsImageFormatHandler *) IsXBM;
+  entry->seekable_stream=MagickTrue;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString(
     "X Windows system bitmap (black and white)");
@@ -577,7 +585,7 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       byte>>=1;
-      if (GetPixelLuma(image,p) < (QuantumRange/2.0))
+      if (GetPixelLuma(image,p) < ((double) QuantumRange/2.0))
         byte|=0x80;
       bit++;
       if (bit == 8)
@@ -626,6 +634,7 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
   }
   (void) CopyMagickString(buffer,"};\n",MaxTextExtent);
   (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
