@@ -17,7 +17,7 @@
 %                                October 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -124,14 +124,14 @@
 %
 */
 
-typedef struct _EdgeInfo
+typedef struct _CensusInfo
 {
   double
     left,
     right,
     top,
     bottom;
-} EdgeInfo;
+} CensusInfo;
 
 static double GetEdgeBackgroundCensus(const Image *image,
   const CacheView *image_view,const GravityType gravity,const size_t width,
@@ -240,7 +240,7 @@ static double GetEdgeBackgroundCensus(const Image *image,
   return(census);
 }
 
-static inline double GetMinEdgeBackgroundCensus(const EdgeInfo *edge)
+static inline double GetMinEdgeBackgroundCensus(const CensusInfo *edge)
 {
   double
     census;
@@ -256,6 +256,10 @@ static RectangleInfo GetEdgeBoundingBox(const Image *image,
   CacheView
     *edge_view;
 
+  CensusInfo
+    edge,
+    vertex;
+
   const char
     *artifact;
 
@@ -263,10 +267,6 @@ static RectangleInfo GetEdgeBoundingBox(const Image *image,
     background_census,
     percent_background;
 
-  EdgeInfo
-    edge,
-    vertex;
-
   Image
     *edge_image;
 
@@ -535,8 +535,8 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
       "GeometryDoesNotContainImage","`%s'",image->filename);
   else
     {
-      bounds.width-=(bounds.x-1);
-      bounds.height-=(bounds.y-1);
+      bounds.width-=(size_t) (bounds.x-1);
+      bounds.height-=(size_t) (bounds.y-1);
     }
   return(bounds);
 }
@@ -1194,7 +1194,7 @@ MagickExport ImageType IdentifyImageType(const Image *image,
 %
 */
 MagickExport MagickBooleanType IsGrayImage(const Image *image,
-  ExceptionInfo *exception)
+  ExceptionInfo *magick_unused(exception))
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
@@ -1231,7 +1231,7 @@ MagickExport MagickBooleanType IsGrayImage(const Image *image,
 %
 */
 MagickExport MagickBooleanType IsMonochromeImage(const Image *image,
-  ExceptionInfo *exception)
+  ExceptionInfo *magick_unused(exception))
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
