@@ -17,7 +17,7 @@
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -77,6 +77,11 @@
 #include "magick/transform.h"
 #include "magick/utility.h"
 
+/*  
+  Define declarations.
+*/
+#define MaxReadRecursionDepth  100
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1224,7 +1229,8 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               (void) AcquireUniqueFilename(image->filename);
               temporary=MagickTrue;
             }
-          (void) CloseBlob(image);
+          if (CloseBlob(image) == MagickFalse)
+            status=MagickFalse;
         }
     }
   if ((magick_info != (const MagickInfo *) NULL) &&
@@ -1330,7 +1336,8 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
           (void) RelinquishUniqueFileResource(write_info->filename);
           status=ImageToFile(image,write_info->filename,exception);
         }
-      (void) CloseBlob(image);
+      if (CloseBlob(image) == MagickFalse)
+        status=MagickFalse;
       (void) RelinquishUniqueFileResource(image->filename);
       (void) CopyMagickString(image->filename,write_info->filename,
         MaxTextExtent);
