@@ -88,25 +88,25 @@ static const PageInfo
     MagickPagesize("4A0", "4768x6741"),
     MagickPagesize("2A0", "3370x4768"),
     MagickPagesize("a0", "2384x3370"),
+    MagickPagesize("a10", "74x105"),
     MagickPagesize("a1", "1684x2384"),
     MagickPagesize("a2", "1191x1684"),
     MagickPagesize("a3", "842x1191"),
-    MagickPagesize("a4", "595x842"),
     MagickPagesize("a4small", "595x842"),
+    MagickPagesize("a4", "595x842"),
     MagickPagesize("a5", "420x595"),
     MagickPagesize("a6", "298x420"),
     MagickPagesize("a7", "210x298"),
     MagickPagesize("a8", "147x210"),
     MagickPagesize("a9", "105x147"),
-    MagickPagesize("a10", "74x105"),
     MagickPagesize("archa", "648x864"),
     MagickPagesize("archb", "864x1296"),
     MagickPagesize("archC", "1296x1728"),
     MagickPagesize("archd", "1728x2592"),
     MagickPagesize("arche", "2592x3456"),
     MagickPagesize("b0", "2920x4127"),
-    MagickPagesize("b1", "2064x2920"),
     MagickPagesize("b10", "91x127"),
+    MagickPagesize("b1", "2064x2920"),
     MagickPagesize("b2", "1460x2064"),
     MagickPagesize("b3", "1032x1460"),
     MagickPagesize("b4", "729x1032"),
@@ -132,8 +132,8 @@ static const PageInfo
     MagickPagesize("folio", "612x936"),
     MagickPagesize("halfletter", "396x612"),
     MagickPagesize("isob0", "2835x4008"),
-    MagickPagesize("isob1", "2004x2835"),
     MagickPagesize("isob10", "88x125"),
+    MagickPagesize("isob1", "2004x2835"),
     MagickPagesize("isob2", "1417x2004"),
     MagickPagesize("isob3", "1001x1417"),
     MagickPagesize("isob4", "709x1001"),
@@ -151,8 +151,8 @@ static const PageInfo
     MagickPagesize("jisb6", "128x182"),
     MagickPagesize("ledger", "1224x792"),
     MagickPagesize("legal", "612x1008"),
-    MagickPagesize("letter", "612x792"),
     MagickPagesize("lettersmall", "612x792"),
+    MagickPagesize("letter", "612x792"),
     MagickPagesize("monarch", "279x540"),
     MagickPagesize("quarto", "610x780"),
     MagickPagesize("statement", "396x612"),
@@ -355,7 +355,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
               if (LocaleNCompare(p,"0x",2) == 0)
                 *width=(size_t) strtol(p,&p,10);
               else
-                *width=((size_t) floor(StringToDouble(p,&p)+0.5)) & 0x7fffffff;
+                *width=CastDoubleToUnsigned(StringToDouble(p,&p)+0.5);
             }
           if (p != q)
             flags|=WidthValue;
@@ -374,7 +374,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
               */
               q=p;
               if (height != (size_t *) NULL)
-                *height=((size_t) floor(StringToDouble(p,&p)+0.5)) & 0x7fffffff;
+                *height=CastDoubleToUnsigned(StringToDouble(p,&p)+0.5);
               if (p != q)
                 flags|=HeightValue;
             }
@@ -393,12 +393,12 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
       }
       q=p;
       if (x != (ssize_t *) NULL)
-        *x=((ssize_t) ceil(StringToDouble(p,&p)-0.5)) & 0x7fffffff;
+        *x=CastDoubleToLong(StringToDouble(p,&p));
       if (p != q)
         {
           flags|=XValue;
           if (((flags & XNegative) != 0) && (x != (ssize_t *) NULL))
-            *x=(-*x);
+            *x=CastDoubleToLong(-1.0**x);
         }
     }
   if ((*p == '+') || (*p == '-'))
@@ -414,12 +414,12 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
       }
       q=p;
       if (y != (ssize_t *) NULL)
-        *y=((ssize_t) ceil(StringToDouble(p,&p)-0.5)) & 0x7fffffff;
+        *y=CastDoubleToLong(StringToDouble(p,&p));
       if (p != q)
         {
           flags|=YValue;
           if (((flags & YNegative) != 0) && (y != (ssize_t *) NULL))
-            *y=(-*y);
+            *y=CastDoubleToLong(-1.0**y);
         }
     }
   if ((flags & PercentValue) != 0)
@@ -487,7 +487,7 @@ MagickExport char *GetPageGeometry(const char *page_geometry)
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",page_geometry);
   (void) CopyMagickString(page,page_geometry,MaxTextExtent);
-  for (i=0; i < (ssize_t) (sizeof(Pagesizes)/sizeof(Pagesizes[0])); i++)
+  for (i=0; *Pagesizes[i].name != '\0'; i++)
   {
     int
       status;
@@ -560,7 +560,7 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case EastGravity:
     case SouthEastGravity:
     {
-      region->x=(ssize_t) (width-region->width-region->x);
+      region->x=CastDoubleToLong((double) width-region->width-region->x);
       break;
     }
     case NorthGravity:
@@ -568,7 +568,7 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case CenterGravity:
     case StaticGravity:
     {
-      region->x+=(ssize_t) (width/2-region->width/2);
+      region->x+=CastDoubleToLong(width/2.0-region->width/2.0);
       break;
     }
     case ForgetGravity:
@@ -584,7 +584,7 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case SouthGravity:
     case SouthEastGravity:
     {
-      region->y=(ssize_t) (height-region->height-region->y);
+      region->y=CastDoubleToLong((double) height-region->height-region->y);
       break;
     }
     case EastGravity:
@@ -592,7 +592,7 @@ MagickExport void GravityAdjustGeometry(const size_t width,
     case CenterGravity:
     case StaticGravity:
     {
-      region->y+=(ssize_t) (height/2-region->height/2);
+      region->y+=CastDoubleToLong(height/2.0-region->height/2.0);
       break;
     }
     case ForgetGravity:
@@ -722,7 +722,7 @@ MagickExport MagickBooleanType IsSceneGeometry(const char *geometry,
 %
 */
 MagickExport MagickBooleanType ListPagesizes(FILE *file,
-  ExceptionInfo *exception)
+  ExceptionInfo *magick_unused(exception))
 {
 #define MaxMagickSpaces  ((int) sizeof(Pagesizes[0].name))
 
@@ -732,6 +732,7 @@ MagickExport MagickBooleanType ListPagesizes(FILE *file,
   ssize_t
     i;
 
+  magick_unreferenced(exception);
   if (file == (FILE *) NULL)
     file=stdout;
   (void) FormatLocaleFile(file,"\nPagesize    Geometry \n");
@@ -1334,8 +1335,8 @@ MagickExport MagickStatusType ParseGravityGeometry(const Image *image,
       scale.y=geometry_info.sigma;
       if ((status & SigmaValue) == 0)
         scale.y=scale.x;
-      region_info->width=(size_t) floor((scale.x*image->columns/100.0)+0.5);
-      region_info->height=(size_t) floor((scale.y*image->rows/100.0)+0.5);
+      region_info->width=CastDoubleToUnsigned(scale.x*image->columns/100.0+0.5);
+      region_info->height=CastDoubleToUnsigned(scale.y*image->rows/100.0+0.5);
     }
   if ((flags & AspectRatioValue) != 0)
     {
@@ -1357,13 +1358,13 @@ MagickExport MagickStatusType ParseGravityGeometry(const Image *image,
       if (geometry_ratio >= image_ratio)
         {
           region_info->width=image->columns;
-          region_info->height=(size_t) floor((double) (image->rows*image_ratio/
-            geometry_ratio)+0.5);
+          region_info->height=CastDoubleToUnsigned((double) image->rows*
+            image_ratio/geometry_ratio+0.5);
         }
       else
         {
-          region_info->width=(size_t) floor((double) (image->columns*
-            geometry_ratio/image_ratio)+0.5);
+          region_info->width=CastDoubleToUnsigned((double) image->columns*
+            geometry_ratio/image_ratio+0.5);
           region_info->height=image->rows;
         }
     }
@@ -1474,8 +1475,8 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       scale.y=geometry_info.sigma;
       if ((flags & SigmaValue) == 0)
         scale.y=scale.x;
-      *width=(size_t) floor(scale.x*former_width/100.0+0.5);
-      *height=(size_t) floor(scale.y*former_height/100.0+0.5);
+      *width=CastDoubleToUnsigned(scale.x*former_width/100.0+0.5);
+      *height=CastDoubleToUnsigned(scale.y*former_height/100.0+0.5);
       former_width=(*width);
       former_height=(*height);
     }
@@ -1497,13 +1498,13 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       if (geometry_ratio >= image_ratio)
         {
           *width=former_width;
-          *height=(size_t) floor((double) (PerceptibleReciprocal(
-            geometry_ratio)*former_height*image_ratio)+0.5);
+          *height=CastDoubleToUnsigned(PerceptibleReciprocal(geometry_ratio)*
+            former_height*image_ratio+0.5);
         }
       else
         {
-          *width=(size_t) floor((double) (PerceptibleReciprocal(
-            image_ratio)*former_width*geometry_ratio)+0.5);
+          *width=CastDoubleToUnsigned(PerceptibleReciprocal(image_ratio)*
+            former_width*geometry_ratio+0.5);
           *height=former_height;
         }
       former_width=(*width);
@@ -1555,8 +1556,10 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
                   (scale_factor < ((double) *height/(double) former_width)))
                 scale_factor=(double) *height/(double) former_width;
             }
-      *width=MagickMax((size_t) floor(scale_factor*former_width+0.5),1UL);
-      *height=MagickMax((size_t) floor(scale_factor*former_height+0.5),1UL);
+      *width=CastDoubleToUnsigned(MagickMax(floor(scale_factor*former_width+
+        0.5),1.0));
+      *height=CastDoubleToUnsigned(MagickMax(floor(scale_factor*former_height+
+        0.5),1.0));
     }
   if ((flags & GreaterValue) != 0)
     {
@@ -1593,10 +1596,10 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
         PerceptibleReciprocal(sqrt(area)));
       if ((scale.x < (double) *width) || (scale.y < (double) *height))
         {
-          *width=(unsigned long) (former_width*PerceptibleReciprocal(
-            distance*PerceptibleReciprocal(sqrt(area))));
-          *height=(unsigned long) (former_height*PerceptibleReciprocal(
-            distance*PerceptibleReciprocal(sqrt(area))));
+          *width=CastDoubleToUnsigned(former_width*PerceptibleReciprocal(
+            distance*PerceptibleReciprocal(sqrt(area)))+0.5);
+          *height=CastDoubleToUnsigned(former_height*PerceptibleReciprocal(
+            distance*PerceptibleReciprocal(sqrt(area)))+0.5);
         }
       former_width=(*width);
       former_height=(*height);
