@@ -17,7 +17,7 @@
 %                            September 1994                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -93,6 +93,7 @@
 #include "magick/string_.h"
 #include "magick/string-private.h"
 #include "magick/timer.h"
+#include "magick/timer-private.h"
 #include "magick/token.h"
 #include "magick/utility.h"
 #include "magick/version.h"
@@ -352,24 +353,24 @@ static ssize_t PrintChannelLocations(FILE *file,const Image *image,
       {
         case RedChannel:
         {
-          match=fabs((double) (p->red-target)) < 0.5 ? MagickTrue : MagickFalse;
+          match=fabs((double) p->red-target) < 0.5 ? MagickTrue : MagickFalse;
           break;
         }
         case GreenChannel:
         {
-          match=fabs((double) (p->green-target)) < 0.5 ? MagickTrue :
+          match=fabs((double) p->green-target) < 0.5 ? MagickTrue :
             MagickFalse;
           break;
         }
         case BlueChannel:
         {
-          match=fabs((double) (p->blue-target)) < 0.5 ? MagickTrue :
+          match=fabs((double) p->blue-target) < 0.5 ? MagickTrue :
             MagickFalse;
           break;
         }
         case AlphaChannel:
         {
-          match=fabs((double) (p->opacity-target)) < 0.5 ? MagickTrue :
+          match=fabs((double) p->opacity-target) < 0.5 ? MagickTrue :
             MagickFalse;
           break;
         }
@@ -480,6 +481,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   char
     color[MaxTextExtent],
     format[MaxTextExtent],
+    iso8601[sizeof("9999-99-99T99:99:99Z")],
     key[MaxTextExtent];
 
   ChannelFeatures
@@ -537,6 +539,12 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   struct stat
     properties;
 
+  struct tm
+    timestamp;
+
+  time_t
+    expired;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
   if (IsEventLogging() != MagickFalse)
@@ -1123,15 +1131,18 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         Display image chromaticity.
       */
       (void) FormatLocaleFile(file,"  Chromaticity:\n");
-      (void) FormatLocaleFile(file,"    red primary: (%g,%g)\n",
-        image->chromaticity.red_primary.x,image->chromaticity.red_primary.y);
-      (void) FormatLocaleFile(file,"    green primary: (%g,%g)\n",
-        image->chromaticity.green_primary.x,
-        image->chromaticity.green_primary.y);
-      (void) FormatLocaleFile(file,"    blue primary: (%g,%g)\n",
-        image->chromaticity.blue_primary.x,image->chromaticity.blue_primary.y);
-      (void) FormatLocaleFile(file,"    white point: (%g,%g)\n",
-        image->chromaticity.white_point.x,image->chromaticity.white_point.y);
+      (void) FormatLocaleFile(file,"    red primary: (%g,%g,%g)\n",
+        image->chromaticity.red_primary.x,image->chromaticity.red_primary.y,
+        image->chromaticity.red_primary.z);
+      (void) FormatLocaleFile(file,"    green primary: (%g,%g,%g)\n",
+        image->chromaticity.green_primary.x,image->chromaticity.green_primary.y,
+        image->chromaticity.green_primary.z);
+      (void) FormatLocaleFile(file,"    blue primary: (%g,%g,%g)\n",
+        image->chromaticity.blue_primary.x,image->chromaticity.blue_primary.y,
+        image->chromaticity.blue_primary.z);
+      (void) FormatLocaleFile(file,"    white point: (%g,%g,%g)\n",
+        image->chromaticity.white_point.x,image->chromaticity.white_point.y,
+        image->chromaticity.white_point.z);
     }
   if ((image->extract_info.width*image->extract_info.height) != 0)
     (void) FormatLocaleFile(file,"  Tile geometry: %.20gx%.20g%+.20g%+.20g\n",
@@ -1462,6 +1473,15 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         image->rows/elapsed_time+0.5),MagickFalse,format);
       (void) FormatLocaleFile(file,"  Pixels per second: %s\n",format);
     }
+  (void) GetMagickUTCTime(&image->timestamp,&timestamp);
+  (void) strftime(iso8601,sizeof(iso8601),"%FT%TZ",&timestamp);
+  expired=' ';
+  if (IsImageTTLExpired(image) != MagickFalse)
+    expired='*';
+  (void) FormatLocaleFile(file,"  Time-to-live: %g:%g:%g:%g%c %s\n",
+    (double) (image->ttl/(3600*24)),(double) ((image->ttl % (24*3600))/3600),
+    (double) ((image->ttl % 3600)/60),(double) ((image->ttl % 3600) % 60),
+    expired,iso8601);
   (void) FormatLocaleFile(file,"  User time: %0.3fu\n",user_time);
   (void) FormatLocaleFile(file,"  Elapsed time: %lu:%02lu.%03lu\n",
     (unsigned long) (elapsed_time/60.0),(unsigned long) ceil(fmod(
