@@ -17,7 +17,7 @@
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -103,6 +103,8 @@ static const MagicMapInfo
     { "CALS", 8, MagicPattern("rorient:") },
     { "CGM", 0, MagicPattern("BEGMF") },
     { "CIN", 0, MagicPattern("\200\052\137\327") },
+    { "CR2", 0, MagicPattern("II\x2a\x00\x10\x00\x00\x00CR\x02") },
+    { "CR2", 0, MagicPattern("MM\x00\x2a\x00\x10\x00\x00RC\x02") },
     { "CRW", 0, MagicPattern("II\x1a\x00\x00\x00HEAPCCDR") },
     { "DCM", 128, MagicPattern("DICM") },
     { "DCX", 0, MagicPattern("\261\150\336\72") },
@@ -179,6 +181,8 @@ static const MagicMapInfo
     { "PSD", 0, MagicPattern("8BPS") },
     { "PWP", 0, MagicPattern("SFW95") },
     { "RAF", 0, MagicPattern("FUJIFILMCCD-RAW ") },
+    { "RAW", 0, MagicPattern("IIU\x00\x08\x00\x00\x00") },
+    { "RW2", 0, MagicPattern("IIU\x00\x18\x00\x00\x00") },
     { "RLE", 0, MagicPattern("\122\314") },
     { "SCT", 0, MagicPattern("CT") },
     { "SFW", 0, MagicPattern("SFW94") },
