@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -87,6 +87,7 @@ static inline void *NTAcquireQuantumMemory(const size_t count,
 }
 
 extern MagickPrivate char
+  *NTGetEnvironmentValue(const char *),
   *NTGetLastError(void);
 
 #if !defined(MAGICKCORE_LTDL_DELEGATE)
@@ -131,7 +132,7 @@ extern MagickPrivate MagickBooleanType
   NTReportEvent(const char *,const MagickBooleanType);
 
 extern MagickExport MagickBooleanType
-  NTLongPathsEnabled();
+  NTLongPathsEnabled(void);
 
 extern MagickPrivate struct dirent
   *NTReadDirectory(DIR *);
