@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -90,9 +90,12 @@
 #include "CLPerfMarker.h"
 #endif
 
-
 #if defined(MAGICKCORE_OPENCL_SUPPORT)
 
+#if defined(MAGICKCORE_LTDL_DELEGATE)
+#include "ltdl.h"
+#endif
+
 #define NUM_CL_RAND_GENERATORS 1024  /* number of random number generators running in parallel */
 #define PROFILE_OCL_KERNELS 0
 
@@ -2454,6 +2457,8 @@ static ds_status AcceleratePerfEvaluator(ds_device *device,
     CloneString(&imageInfo->size,ACCELERATE_PERF_DIMEN);
     CopyMagickString(imageInfo->filename,"xc:none",MaxTextExtent);
     inputImage=ReadImage(imageInfo,exception);
+    if (inputImage == (Image *) NULL)
+      ReturnStatus(DS_PERF_EVALUATOR_ERROR);
 
     initAccelerateTimer(&timer);
 
