@@ -62,7 +62,9 @@
 #include "magick/string-private.h"
 #include "magick/splay-tree.h"
 #include "magick/thread-private.h"
+#include "magick/timer-private.h"
 #include "magick/token.h"
+#include "magick/timer-private.h"
 #include "magick/utility.h"
 #include "magick/utility-private.h"
 
@@ -72,7 +74,7 @@
 #define MagickPathTemplate "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"  /* min 6 X's */
 #define NumberOfResourceTypes  \
   (sizeof(resource_semaphore)/sizeof(*resource_semaphore))
-
+
 /*
   Typedef declarations.
 */
@@ -125,8 +127,8 @@ static ResourceInfo
     MagickULLConstant(0),                 /* initial thread */
     MagickULLConstant(0),                 /* initial throttle */
     MagickULLConstant(0),                 /* initial time */
-    MAGICK_SSIZE_MAX/sizeof(PixelPacket), /* width limit */
-    MAGICK_SSIZE_MAX/sizeof(PixelPacket), /* height limit */
+    (MagickSizeType) (MAGICK_SSIZE_MAX/sizeof(PixelPacket)/5), /* width limit */
+    (MagickSizeType) (MAGICK_SSIZE_MAX/sizeof(PixelPacket)/5), /* height limit */
     MagickResourceInfinity,               /* list length limit */
     MagickULLConstant(3072)*1024*1024,    /* area limit */
     MagickULLConstant(1536)*1024*1024,    /* memory limit */
@@ -135,7 +137,7 @@ static ResourceInfo
     MagickULLConstant(768),               /* file limit */
     MagickULLConstant(1),                 /* thread limit */
     MagickULLConstant(0),                 /* throttle limit */
-    MagickResourceInfinity                /* time limit */
+    MagickULLConstant(0),                 /* time limit */
   };
 
 static SemaphoreInfo
@@ -385,12 +387,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
     case TimeResource:
     {
       limit=resource_info.time_limit;
-      if (((MagickSizeType) resource_info.time+request) >
-          (MagickSizeType) resource_info.time)
+      if (((MagickSizeType) resource_info.time+request) > (MagickSizeType) resource_info.time)
         {
           resource_info.time+=request;
-          if ((limit == MagickResourceInfinity) ||
-              ((MagickSizeType) resource_info.time < limit))
+          if ((limit == 0) || ((MagickSizeType) resource_info.time < limit))
             status=MagickTrue;
           else
             resource_info.time-=request;
@@ -953,12 +953,10 @@ static ssize_t FormatPixelSize(const MagickSizeType size,
     length;
 
   ssize_t
+    count,
     i,
     j;
 
-  ssize_t
-    count;
-
   static const char
     *bi_units[] =
     {
@@ -994,6 +992,64 @@ static ssize_t FormatPixelSize(const MagickSizeType size,
   return(count);
 }
 
+static void FormatTimeToLive(const MagickSizeType ttl,char *timeString)
+{
+  MagickSizeType
+    days,
+    hours,
+    minutes,
+    months,
+    seconds,
+    weeks,
+    years;
+
+  years=ttl/31536000;
+  seconds=ttl % 31536000;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld years",years);
+      return;
+    }
+  months=ttl/2628000;
+  seconds=ttl % 2628000;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld months",
+        months);
+      return;
+    }
+  weeks=ttl/604800;
+  seconds=ttl % 604800;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld weeks",weeks);
+      return;
+    }
+  days=ttl/86400;
+  seconds=ttl % 86400;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld days",days);
+      return;
+    }
+  hours=ttl/3600;
+  seconds=ttl % 3600;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld hours",hours);
+      return;
+    }
+  minutes=ttl/60;
+  seconds=ttl % 60;
+  if (seconds == 0)
+    {
+      (void) FormatLocaleString(timeString,MagickPathExtent,"%lld minutes",
+        minutes);
+      return;
+    }
+  (void) FormatLocaleString(timeString,MagickPathExtent,"%lld seconds",ttl);
+}
+
 MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   ExceptionInfo *magick_unused(exception))
 {
@@ -1027,9 +1083,8 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   if (resource_info.disk_limit != MagickResourceInfinity)
     (void) FormatMagickSize(resource_info.disk_limit,MagickTrue,disk_limit);
   (void) CopyMagickString(time_limit,"unlimited",MaxTextExtent);
-  if (resource_info.time_limit != MagickResourceInfinity)
-    (void) FormatLocaleString(time_limit,MaxTextExtent,"%.20g",(double)
-      ((MagickOffsetType) resource_info.time_limit));
+  if (resource_info.time_limit != 0)
+    FormatTimeToLive(resource_info.time_limit,time_limit);
   (void) FormatLocaleFile(file,"Resource limits:\n");
   (void) FormatLocaleFile(file,"  Width: %s\n",width_limit);
   (void) FormatLocaleFile(file,"  Height: %s\n",height_limit);
@@ -1220,7 +1275,6 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
     {
       resource_info.time-=size;
       assert(resource_info.time >= 0);
-      if (logging != MagickFalse)
       if (logging != MagickFalse)
         {
           (void) FormatMagickSize((MagickSizeType) resource_info.time,
@@ -1464,11 +1518,12 @@ MagickExport MagickBooleanType ResourceComponentGenesis(void)
         100.0));
       limit=DestroyString(limit);
     }
-  (void) SetMagickResourceLimit(TimeResource,MagickResourceInfinity);
+  (void) SetMagickResourceLimit(TimeResource,0);
   limit=GetEnvironmentValue("MAGICK_TIME_LIMIT");
   if (limit != (char *) NULL)
     {
-      (void) SetMagickResourceLimit(TimeResource,StringToSizeType(limit,100.0));
+      (void) SetMagickResourceLimit(TimeResource,(MagickSizeType)
+        ParseMagickTimeToLive(limit));
       limit=DestroyString(limit);
     }
   (void) SetMagickResourceLimit(ListLengthResource,MagickResourceInfinity);
@@ -1659,8 +1714,8 @@ MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
       if (value == (char *) NULL)
         resource_info.time_limit=limit;
       else
-        resource_info.time_limit=MagickMin(limit,StringToSizeType(value,100.0));
-      ResetPixelCacheEpoch();
+        resource_info.time_limit=MagickMin(limit,(MagickSizeType)
+          ParseMagickTimeToLive(value));
       break;
     }
     case WidthResource:
